# Man exec

> exec <command>  [arguments] - In shell mode, it will run a command on the operating system and print the results. You can also start the line with an exclamation mark to achieve the same effect.

## Usage

`exec ls -la ~/.askGPT/`

`!pwd`